@@ -55,7 +55,8 @@ class CreateForm(forms.SelfHandlingForm):
                                    'data-switch-on': 'audit_type',
                                    'data-audit_type-continuous':
                                    _("Interval (in seconds or cron"
-                                     " format)")}))
+                                     " format)")}),
+                               required=False)
     failure_url = 'horizon:admin:audits:index'
     auto_trigger = forms.BooleanField(label=_("Auto Trigger"),
                                       required=False)
@@ -85,6 +86,14 @@ class CreateForm(forms.SelfHandlingForm):
             choices.insert(0, ("", _("No Audit Template found")))
         return choices
 
+    def clean(self):
+        cleaned_data = super(CreateForm, self).clean()
+        audit_type = cleaned_data.get('audit_type')
+        if audit_type == 'continuous' and not cleaned_data.get('interval'):
+            msg = _('Please input an interval for continuous audit')
+            raise forms.ValidationError(msg)
+        return cleaned_data
+
     def handle(self, request, data):
         try:
             params = {'audit_template_uuid': data.get('audit_template')}
@@ -100,8 +109,8 @@ class CreateForm(forms.SelfHandlingForm):
             messages.success(request, message)
             return audit
         except Exception as exc:
-            if exc.http_status == 409:
-                msg = _('Quota exceeded for resource audit.')
+            if getattr(exc, 'http_status', None) == 409:
+                msg = _('Error: Audit name already exists.')
             else:
                 msg = _('Failed to create audit.')
             LOG.info(exc)
